@@ -163,6 +163,12 @@ def annotate(sequence,options):
         
         
     ip = iter(options.finder)
+    
+                    #
+                    # Iterate over the direct primers
+                    # until one match on direct or reverse strand
+                    #
+                    
     while direct is None:
         try:
             alid,alir=ip.next()
@@ -174,6 +180,10 @@ def annotate(sequence,options):
         except StopIteration:
             break 
         
+                    # If a direct primer match
+                    # look for corresponding reverse primer
+                    # on the ooposite strand
+                    
     if direct is not None:
         pdirect=str(alid.seqB)
         
@@ -190,12 +200,17 @@ def annotate(sequence,options):
             except StopIteration:
                 break
         
+                # if direct and reverse primers are found then 
+                # compute the length of the applicon
+        
         if reverse is not None:
             preverse=str(alid.seqB)
             if strand :
                 lampli = reverse[1]-direct[2]
             else:
                 lampli = direct[1]-reverse[2]
+        
+                # Check for tags if present
             
         ltag = options.primers[pdirect][0]
         
@@ -225,6 +240,9 @@ def annotate(sequence,options):
                 if treverse is not None and len(treverse)!=ltag:
                     treverse=None
                     
+                    
+                # both primers are found
+                
     if direct is not None and reverse is not None:
         if strand:
             fragment = sequence[direct[2]:reverse[1]]
@@ -239,10 +257,15 @@ def annotate(sequence,options):
                 quality.reverse()
         else:
             quality=None
+            
+                # Only direct primer is found
+                
     elif direct is not None and reverse is None:
         if strand:
+            print "direct partial"
             fragment = sequence[direct[2]:]
         else:
+            print "reverse partial"
             fragment = sequence[0:direct[1]].complement()
         if hasattr(sequence, 'quality'):
             if strand:
