@@ -1,7 +1,8 @@
 
 
 from _nws import NWS
-from _lcs import LCS
+from _upperbond import indexSequences
+from _lcs import LCS,lenlcs
 from _assemble import DirectAssemble, ReverseAssemble
 from _qsassemble import QSolexaDirectAssemble,QSolexaReverseAssemble 
 from _rassemble import RightDirectAssemble as RightReverseAssemble
